@@ -9,13 +9,14 @@ sub init {
     $self->use_class('config');
 }
 
-sub boolean_arguments { qw( -new -make -start) }
+sub boolean_arguments { qw( -new -make -start -upgrade) }
 sub process {
     my $self = shift;
     my $args = $self->parse_arguments(@_);
     return $self->new_spork if $args->{-new};
     return $self->make_spork if $args->{-make};
     return $self->start_spork if $args->{-start};
+    return $self->upgrade_spork if $args->{-upgrade};
     return $self->usage;
 }
 
@@ -24,24 +25,29 @@ sub new_spork {
     my @files = io('.')->all;
     die "Can't make new spork in a non-empty directory\n"
       if @files;
-    $self->use_class('files');
-    $self->files->extract_files;
+    $self->use_class('slides');
+    $self->slides->extract_files;
     $self->config->extract_files;
 }
 
 sub make_spork {
-    my $spork = Spork->new;
-    my $hub = $spork->load_hub('config.yaml');
-    my $self = $hub->load_class('command');
+    my $self = shift;
+#     my $spork = Spork->new;
+#     my $hub = $spork->load_hub;
+#     my $self = $hub->load_class('command');
+    $self->use_class('template');
+    $self->template->extract_files
+      unless -e $self->template->extract_to;
     $self->use_class('slides');
     $self->slides->make_slides;
     $self->slides->copy_files;
 }
 
 sub start_spork {
-    my $spork = Spork->new;
-    my $hub = $spork->load_hub('config.yaml');
-    my $self = $hub->load_class('command');
+    my $self = shift;
+#     my $spork = Spork->new;
+#     my $hub = $spork->load_hub('config.yaml');
+#     my $self = $hub->load_class('command');
     my $command = $self->config->start_command
       or die "No start_command in configuration";
     warn $command, "\n";
@@ -51,9 +57,9 @@ sub start_spork {
 sub usage {
     warn <<END;
 usage:
-  spork -new
-  spork -make
-  spork -start
+  spork -new                  # Generate a new slideshow in an empty directory
+  spork -make                 # Turn the text into html slides
+  spork -start                # Start the show in a browser
 END
 }
 
